@@ -1,11 +1,11 @@
-setGeneric("madDiff", function(x, na.rm=FALSE, diff=1, ...) {
+setGeneric("madDiff", function(x, na.rm=FALSE, diff=1L, ...) {
   standardGeneric("madDiff");
 })
 
-setMethod("madDiff", signature(x="numeric"), function(x, na.rm=FALSE, diff=1, ...) {
+setMethod("madDiff", signature(x="numeric"), function(x, na.rm=FALSE, diff=1L, ...) {
   if (na.rm)
     x <- x[!is.na(x)];
-  if (diff > 0)
+  if (diff > 0L)
     x <- diff(x, differences=diff);
   mad(x, na.rm=FALSE, ...)/(sqrt(2)^diff);
 })
@@ -18,4 +18,4 @@ setMethod("madDiff", signature(x="numeric"), function(x, na.rm=FALSE, diff=1, ..
 # o Added varDiff().
 # 2008-04-10 [on UA930 SFO-LHR]
 # o Created.
-############################################################################  
+############################################################################
