@@ -17,13 +17,13 @@ stopifnot(all.equal(xM, xM0))
 
 # Weighted row averages (excluding some columns)
 w <- c(1,1,0,1)
-xM0 <- rowMedians(x[,(w == 1),drop=FALSE]);
+xM0 <- rowMedians(x[,(w == 1),drop=FALSE])
 xM <- rowWeightedMedians(x, w=w)
 stopifnot(all.equal(xM, xM0))
 
 # Weighted row averages (excluding some columns)
 w <- c(0,1,0,0)
-xM0 <- rowMedians(x[,(w == 1),drop=FALSE]);
+xM0 <- rowMedians(x[,(w == 1),drop=FALSE])
 xM <- rowWeightedMedians(x, w=w)
 stopifnot(all.equal(xM, xM0))
 
